import Generator from 'yeoman-generator';
import type { RepoAppDownloadOptions } from './types';
import { PromptNames } from './types';
/**
 * Generator class for downloading a basic app from a repository.
 * This class handles the process of app selection, downloading the app and generating a fiori app from the downloaded app
 */
export default class extends Generator {
    private readonly appWizard;
    private readonly vscode?;
    private readonly appRootPath;
    private readonly prompts;
    private readonly answers;
    options: RepoAppDownloadOptions;
    private projectPath;
    private extractedProjectPath;
    setPromptsCallback: (fn: object) => void;
    /**
     * Constructor for Downloading App.
     *
     * @param args - arguments passed to the generator
     * @param opts - options passed to the generator
     */
    constructor(args: string | string[], opts: RepoAppDownloadOptions);
    /**
     * Initialises necessary settings and telemetry for the generator.
     */
    initializing(): Promise<void>;
    /**
     * Prompts the user for application details and downloads the app.
     */
    prompting(): Promise<void>;
    /**
     * Writes the configuration files for the project, including deployment config, and README.
     */
    writing(): Promise<void>;
    /**
     * Returns the configuration for the README file.
     *
     * @param config - The app configuration object.
     * @returns {ReadMe} The configuration for generating the README.
     */
    private _getReadMeConfig;
    /**
     * Returns the configuration for launching the app with Fiori options.
     *
     * @param config - The app configuration object.
     * @returns {FioriOptions} The launch configuration options.
     */
    private _getLaunchConfig;
    /**
     * Installs npm dependencies for the project.
     */
    install(): Promise<void>;
    /**
     * Runs npm install in the specified path.
     *
     * @param path - The path to run npm install.
     */
    private _runNpmInstall;
    /**
     * Responsible for updating workspace folders and running post-generation commands if defined.
     */
    private _handlePostAppGeneration;
    /**
     * Finalises the generator process by creating launch configurations and running post-generation hooks.
     */
    end(): Promise<void>;
}
export { PromptNames };
export type { RepoAppDownloadOptions };
//# sourceMappingURL=index.d.ts.map