"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readManifest = exports.makeValidJson = void 0;
const constants_1 = require("./constants");
const i18n_1 = require("./i18n");
const logger_1 = __importDefault(require("./logger"));
/**
 *
 * @param filePath - Path to the JSON file
 * @param fs - File system editor instance
 * @returns - Parsed JSON object
 */
function makeValidJson(filePath, fs) {
    try {
        // Read the file contents
        const fileContents = fs.read(filePath);
        const validJson = JSON.parse(fileContents);
        return validJson;
    }
    catch (error) {
        throw new Error((0, i18n_1.t)('error.errorProcessingJsonFile', { error }));
    }
}
exports.makeValidJson = makeValidJson;
/**
 * Reads and validates the `manifest.json` file.
 *
 * @param {string} manifesFilePath - Manifest file path.
 * @param {Editor} fs - The file system editor.
 * @returns {Manifest} The validated manifest object.
 */
function readManifest(manifesFilePath, fs) {
    if (!fs.exists(manifesFilePath)) {
        logger_1.default.logger?.error((0, i18n_1.t)('error.readManifestErrors.manifestFileNotFound'));
    }
    const manifest = fs.readJSON(manifesFilePath);
    if (!manifest) {
        logger_1.default.logger?.error((0, i18n_1.t)('error.readManifestErrors.readManifestFailed'));
    }
    if (!manifest?.['sap.app']) {
        logger_1.default.logger?.error((0, i18n_1.t)('error.readManifestErrors.sapAppNotDefined'));
    }
    if (manifest?.['sap.app']?.sourceTemplate?.id !== constants_1.adtSourceTemplateId) {
        logger_1.default.logger?.error((0, i18n_1.t)('error.readManifestErrors.sourceTemplateNotSupported'));
    }
    return manifest;
}
exports.readManifest = readManifest;
//# sourceMappingURL=file-helpers.js.map