import type { AppIndex } from '@sap-ux/axios-extension';
import type { ValidationLink } from '@sap-ux/inquirer-common';
import type { AppInfo, QuickDeployedAppConfig, QfaJsonConfig } from '../app/types';
/**
 * Validates the entire app configuration.
 *
 * @param {QfaJsonConfig} config - The QFA JSON configuration containing app details.
 * @returns {boolean} - Returns true if the configuration is valid, false otherwise.
 */
export declare const validateQfaJsonFile: (config: QfaJsonConfig) => boolean;
/**
 * Validates the prompt state for the app download process.
 *
 * @param {string} targetFolder - The target folder for the app download.
 * @param {string} [appId] - The selected app id.
 * @returns {boolean} - Returns true if the prompt state is valid, false otherwise.
 */
export declare const isValidPromptState: (targetFolder: string, appId?: string) => boolean;
/**
 * Validates the app selection and handles app download if applicable.
 *
 * @param answers - The selected app information.
 * @param appList - The list of available apps.
 * @param quickDeployedAppConfig - The quick deployed app configuration.
 * @returns A promise resolving to a boolean or a validation error message.
 */
export declare function validateAppSelection(answers: AppInfo, appList: AppIndex, quickDeployedAppConfig?: QuickDeployedAppConfig): Promise<string | boolean | ValidationLink>;
//# sourceMappingURL=validators.d.ts.map